# Fedora 10 onwards support noarch subpackages; by using one, we can
# put the arch-independent data in a common subpackage and save lots
# of space on the mirrors
%if 0%{?fedora} > 9
%global shared_data_package 1
%else
%global shared_data_package 0
%endif

Name:		bluefish
Version:	1.0.7
Release:	6%{?dist}
Summary:	GTK2 web development application for experienced users
Group:		Development/Tools
License:	GPLv2+
URL:		http://bluefish.openoffice.nl/
Source0:	http://www.bennewitz.com/bluefish/stable/source/bluefish-%{version}.tar.bz2
Patch0:		bluefish-1.0.7-syntax-highlight.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:	aspell-devel >= 0.5
BuildRequires:	desktop-file-utils
BuildRequires:	gettext
BuildRequires:	gnome-vfs2-devel
BuildRequires:	gtk2-devel >= 2.0.6
BuildRequires:	libgnomeui-devel >= 2.6
BuildRequires:	pcre-devel >= 3.9
# gail-devel needed because libgnomeui->libgnomecanvas chain doesn't pull it
# in (at least on F-9), and libgnomeui detection fails because of
# requires.private gail in libgnomecanvas-2.0.pc
BuildRequires:	gail-devel
%if %{shared_data_package}
Requires:	bluefish-shared-data = %{version}-%{release}
%else
# Requires for directory ownership
Requires:	gnome-mime-data, shared-mime-info
%endif

%description
Bluefish is a powerful editor for experienced web designers and programmers.
Bluefish supports many programming and markup languages, but it focuses on
editing dynamic and interactive websites.

%if %{shared_data_package}
%package shared-data
Summary:	Architecture-independent data for bluefish
Group:		Development/Tools
BuildArch:	noarch
# Requires for directory ownership
Requires:	gnome-mime-data, shared-mime-info

%description shared-data
Files common to every architecture version of bluefish.
%endif

%prep
%setup -q
%patch0 -p0

%build
%configure --disable-update-databases
%{__make} %{?_smp_mflags}

%install
%{__rm} -rf %{buildroot}
%{__mkdir_p} %{buildroot}%{_datadir}/applications
%{__make} install DESTDIR=%{buildroot} INSTALL_PROGRAM="%{__install} -m 755"

%find_lang %{name}
/usr/bin/desktop-file-install --vendor fedora --delete-original \
	--dir %{buildroot}%{_datadir}/applications		\
	%{buildroot}%{_datadir}/applications/bluefish.desktop
/usr/bin/desktop-file-install --vendor fedora --delete-original \
	--dir %{buildroot}%{_datadir}/applications		\
	%{buildroot}%{_datadir}/applications/bluefish-project.desktop

# Manually install docs so that they go into
# %{_defaultdocdir}/bluefish-%{version} even if we put them in the
# shared-data subpackage
%{__install} -d %{buildroot}%{_defaultdocdir}/bluefish-%{version}
%{__install} -m 644 -p -t %{buildroot}%{_defaultdocdir}/bluefish-%{version}/ \
	AUTHORS ChangeLog COPYING NEWS README TODO

%clean
%{__rm} -rf %{buildroot}

%post
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
/usr/bin/update-desktop-database &> /dev/null || :

%postun
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
/usr/bin/update-desktop-database &> /dev/null || :

%if %{shared_data_package}
%files
%defattr(-,root,root,-)
%else
%files -f %{name}.lang
%defattr(-,root,root,-)
%endif
%{_bindir}/bluefish

%if %{shared_data_package}
%files shared-data -f %{name}.lang
%defattr(-,root,root,-)
%endif
%{_datadir}/applications/fedora-bluefish.desktop
%{_datadir}/applications/fedora-bluefish-project.desktop
%{_datadir}/application-registry/*
%{_datadir}/bluefish/
%{_datadir}/mime/packages/bluefish.xml
%{_datadir}/mime-info/*
%{_datadir}/pixmaps/*
%{_defaultdocdir}/bluefish-%{version}/
%{_mandir}/man1/bluefish.1*

%changelog
* Thu Feb 26 2009 Paul Howarth <paul@city-fan.org> - 1.0.7-6
- Split off shared-data noarch subpackage for Fedora 10 onwards
- Add buildreq gail-devel to fix broken detection of libgnomeui on F-9

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.7-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Feb 14 2008 Paul Howarth <paul@city-fan.org> - 1.0.7-4
- rebuild with gcc 4.3.0 for Fedora 9

* Mon Jan 21 2008 Paul Howarth <paul@city-fan.org> - 1.0.7-3
- include patch from upstream VCS to work around problem editing syntax
  highlighting patterns (#390871)

* Sun Aug 26 2007 Paul Howarth <paul@city-fan.org> - 1.0.7-2
- clarify license as GPL version 2 or later
- unexpand tabs in spec
- update scriptlets and drop scriptlet dependencies

* Mon Nov  6 2006 Paul Howarth <paul@city-fan.org> - 1.0.7-1
- update to 1.0.7
- update download URL
- don't add category X-Fedora in desktop files

* Tue Aug 29 2006 Paul Howarth <paul@city-fan.org> - 1.0.5-4
- rebuild for dynamic linking speedups (FE6)

* Mon May 22 2006 Paul Howarth <paul@city-fan.org> - 1.0.5-3
- fix broken debuginfo packages by not stripping binaries (#192617)
- cosmetic changes to spec file
- add extra doc files AUTHORS ChangeLog NEWS README TODO
- use full command paths for reproducible builds

* Thu Feb 16 2006 Paul Howarth <paul@city-fan.org> - 1.0.5-2
- rebuild

* Mon Feb  6 2006 Paul Howarth <paul@city-fan.org> - 1.0.5-1
- update to 1.0.5
- include manpage

* Mon Sep  5 2005 Paul Howarth <paul@city-fan.org> - 1.0.4-1
- update to 1.0.4

* Sun Aug 21 2005 Paul Howarth <paul@city-fan.org> - 1.0.3-1
- update to 1.0.3

* Sat Aug 20 2005 Michael Schwendt <mschwendt[AT]users.sf.net> - 1.0.2-3
- rebuilt

* Fri Jul 29 2005 Paul Howarth <paul@city-fan.org> - 1.0.2-2
- buildrequire libgnomeui-devel, not libgnomeui

* Fri Jul 29 2005 Paul Howarth <paul@city-fan.org> - 1.0.2-1
- update to 1.0.2
- add dist tag
- add libgnomeui support as per upstream package (#161234, #163804)
- add project desktop entry
- desktop entry munging not needed

* Sun May 22 2005 Jeremy Katz <katzj@redhat.com> - 1.0-4
- rebuild on all arches

* Fri Apr  7 2005 Michael Schwendt <mschwendt[AT]users.sf.net>
- rebuilt

* Sun Feb 20 2005 Phillip Compton <pcompton[AT]proteinmedia.com> 1.0-2
- Fix for absolute path to icon in desktop entry.

* Tue Jan 11 2005 Phillip Compton <pcompton[AT]proteinmedia.com> 1.0-1
- 1.0.

* Sat Jan 01 2005 Phillip Compton <pcompton[AT]proteinmedia.com> 1.0-0.1.cvs20041231
- cvs20041231

* Fri Nov 12 2004 Phillip Compton <pcompton[AT]proteinmedia.com> 0.13-0.fdr.4
- Redirect output for post/postun.
- More mime-types in desktop entry.
- Fix changelog.

* Thu Nov 11 2004 Phillip Compton <pcompton[AT]proteinmedia.com> 0.13-0.fdr.3
- Updated .desktop entry for new mime-type system.
- Added post/postun update-desktop-database.
- Removed files from old mime-type system.

* Mon Apr 12 2004 Phillip Compton <pcompton[AT]proteinmedia.com> 0:0.13-0.fdr.2
- Now including .applications file and mime info.

* Sat Apr 10 2004 Phillip Compton <pcompton[AT]proteinmedia.com> 0:0.13-0.fdr.1
- Updated to 0.13.

* Mon Nov 24 2003 Phillip Compton <pcompton[AT]proteinmedia.com> 0:0.12-0.fdr.1
- Updated to 0.12.
- BuildReq gnome-vfs2-devel.

* Sun Oct 17 2003 Phillip Compton <pcompton[AT]proteinmedia.com> 0.11-0.fdr.5
- Release detection dropped..1

* Mon Oct 06 2003 Phillip Compton <pcompton[AT]proteinmedia.com> 0:0.11-0.fdr.4
- Improved release detection.

* Sun Sep 28 2003 Phillip Compton <pcompton[AT]proteinmedia.com> 0:0.11-0.fdr.3
- Modified for Fedora Core release detection.
- Updated description.

* Mon Sep 15 2003 Phillip Compton <pcompton[AT]proteinmedia.com> 0:0.11-0.fdr.2
- Now auto-detecting RH release.

* Sun Jul 27 2003 Phillip Compton <pcompton[AT]proteinmedia.com> 0:0.11-0.fdr.1
- Updated to 0.11.

* Fri Jul 25 2003 Phillip Compton <pcompton[AT]proteinmedia.com> 0:0.10-0.fdr.2
- Enable feature diferention for shrike vs severn.
- BuildReq aspell-devel for severn.
- in bluefish.desktop: Terminal=0 => Terminal=false.
- Source0 path updated.

* Thu Jul 17 2003 Phillip Compton <pcompton[AT]proteinmedia.com> 0:0.10-0.fdr.1
- Updated to 0.10.

* Thu Jul 17 2003 Phillip Compton <pcompton[AT]proteinmedia.com> 0:0.10-0.fdr.0.1.20030716
- 2003-07-16 snapshot.

* Thu Apr 10 2003 Phillip Compton <pcompton[AT]proteinmedia.com> 0:0.9-0.fdr.5
- Added gettext to BuildRequires.

* Tue Apr 01 2003 Phillip Compton <pcompton[AT]proteinmedia.com> 0:0.9-0.fdr.4
- Changed category to X-Fedora-Extra.
- Added Epoch:0.
- Removed redundant Requires entries.

* Sun Mar 23 2003 Phillip Compton <pcompton[AT]proteinmedia.com> 0.9-0.fdr.3
- Updated for inclusion in fedora

* Wed Mar 05 2003 Phillip Compton <pcompton[AT]proteinmedia.com> 0.9-0.fdr.2
- Cleaned up spec file

* Wed Feb 19 2003 Phillip Compton <pcompton[AT]proteinmedia.com> 0.9-1.fedora.1
- Updated to 0.9

* Sat Feb 8 2003 Phillip Compton
- Update to snapshot: 20030207

* Wed Feb 5 2003 Phillip Compton
- Update to snapshot: 20030205

* Wed Jan 15 2003 Matthias Saou <matthias.saou@est.une.marmotte.net>
- Update to the latest snapshot which should be more stable.

* Sat Jan 11 2003 Matthias Saou <matthias.saou@est.une.marmotte.net>
- Update to 0.8.
- Major spec file updates based on the one from Matthias Haase.

* Thu May  2 2002 Matthias Saou <matthias.saou@est.une.marmotte.net>
- Rebuilt against Red Hat Linux 7.3.
- Added the %{?_smp_mflags} expansion.

* Mon Nov 19 2001 Matthias Saou <matthias.saou@est.une.marmotte.net>
- Update to 0.7.
- Spec file simplifications since the build is now cleaner :-)

* Wed May  2 2001 Matthias Saou <matthias.saou@est.une.marmotte.net>
- Spec file cleanup for Red Hat 7.1.
- Added a GNOME desktop entry.
- Compiled with kgcc and reported the problems encountered with gcc 2.96.

* Fri May 5 2000 Bo Forslund <bo.forslund@abc.se>
- fine tuning of the spec file
- possible to build with all processors on smp machines
- an entry for RedHats wmconfig

* Tue Mar 21 2000 CW Zuckschwerdt <zany@triq.net>
- complete rewrite of spec file
- relocateable on build-time
- no privileges required while building
- fix for install_location (should really be $(LIBDIR)/bluefish!)
- included man, locale and lib into RPM (was seriously broken)

* Thu Jan 13 2000 Chris Lea <chrislea@luciddesigns.com>
- Fixed up spec file some. bluefish-0.3.5

* Wed Nov 17 1999 Chris Lea <chrislea@luciddesigns.com>
- added spec file. this is my third RPM that I've made a spec
  file for, so please be merciful if I've screwed something up
